/*
 * Copyright (c) 2007 Klaus Dorer
 * Hochschule Offenburg
 */
package kdo.domain;

/**
 * @author cfueller
 *
 */
public interface IOptimizationState extends IProblemState, Comparable<IOptimizationState> {
	/**
	 * @param other the state to compare against
	 * @return the relative number of values that differ for this and the passed
	 *         state
	 */
	float getRelativeDiversity(IOptimizationState other);

	/**
	 * Checks the consistency of this state to be defined by each problem state
	 * separately
	 */
	public void checkConsistency();

	/**
	 * Gets the values of the optimization state
	 * @return The state as a array of float values
	 */
	public float[] getState();

	/**
	 * Gets the iterations passed for this ProblemState
	 * @return the iterations passed
	 */
	public int getIteration();

	/**
	 * increments the iterations passed for this ProblemState
	 */
	public void incrementIteration();

	/**
	 * calculates the utility
	 * @return the calculated utility
	 */
	public float calculateFitness();
}
