/**
 *
 */
package kdo.domain.model;

import java.util.Comparator;

import kdo.domain.IOptimizationState;
import kdo.domain.IProblem;
import kdo.util.learningParameter.LearningParameterMap;

/**
 * @author Mithril
 *
 */
public abstract class OptimizationState extends ProblemState implements IOptimizationState
{
	protected float[] state;

	protected int iteration;

	/**
	 * @param problem
	 * @param state
	 */
	public OptimizationState(IProblem problem, float[] state)
	{
		this(problem, state, null);
	}

	/**
	 * @param problem
	 * @param state
	 */
	public OptimizationState(IProblem problem, float[] state, LearningParameterMap params)
	{
		super(problem, params);
		this.state = state;
		iteration = 0;
	}

	/* (non-Javadoc)
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	@Override
	public int compareTo(IOptimizationState o)
	{
		return Float.compare(getUtility(), o.getUtility());
	}

	/* (non-Javadoc)
	 * @see kdo.domain.IOptimizationState#getRelativeDiversity(kdo.domain.IOptimizationState)
	 */
	@Override
	public float getRelativeDiversity(IOptimizationState other)
	{
		float[] state1 = getState();
		float[] state2 = other.getState();
		int sum = 0;
		for (int i = 0; i < state1.length; i++) {
			if (state1[i] != state2[i]) {
				sum++;
			}
		}
		return sum / (float) state1.length;
	}

	/* (non-Javadoc)
	 * @see kdo.domain.IOptimizationState#getState()
	 */
	@Override
	public float[] getState()
	{
		return state;
	}

	/* (non-Javadoc)
	 * @see kdo.domain.IOptimizationState#getIteration()
	 */
	@Override
	public int getIteration()
	{
		return iteration;
	}

	/* (non-Javadoc)
	 * @see kdo.domain.IOptimizationState#incrementIteration()
	 */
	@Override
	public void incrementIteration()
	{
		iteration++;
	}

	/**
	 * Compares the states by iteration (ascending)
	 * @author cfueller
	 */
	public static class StateIterationComparator implements Comparator<IOptimizationState>
	{
		/**
		 * @see Comparator#compare(Object, Object)
		 */
		@Override
		public int compare(IOptimizationState o1, IOptimizationState o2)
		{
			if (o1.getIteration() < o2.getIteration()) {
				return -1;
			} else if (o1.getIteration() > o2.getIteration()) {
				return 1;
			}
			return 0;
		}
	}

	/**
	 * Compares the states by utility (ascending)
	 * @author cfueller
	 */
	public static class StateUtilityComparator implements Comparator<IOptimizationState>
	{
		/**
		 * @see Comparator#compare(Object, Object)
		 */
		@Override
		public int compare(IOptimizationState o1, IOptimizationState o2)
		{
			if (o1.getUtility() < o2.getUtility()) {
				return -1;
			} else if (o1.getUtility() > o2.getUtility()) {
				return 1;
			}
			return 0;
		}
	}
}
