/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.domain.model;

import java.util.Iterator;

import kdo.domain.IIndividuum;
import kdo.domain.IOperator;
import kdo.domain.IProblemState;

/**
 * Base class for Parameter adjustment neighborhood
 */
public class ParameterChangeIterator extends OperatorIteratorBase implements Iterator<IOperator>
{
	/** index of the previously changed parameter, -1 if not started */
	private int currentIndex;

	/** true if the current operator has been decreased already */
	private boolean decreased;

	/**
	 * stepSizes array containing the delta values by which to adjust each
	 * parameter
	 */
	private float[] stepSizes;

	/**
	 * Default constructor
	 * @param stepSizes array containing the delta values by which to adjust each
	 *        parameter
	 */
	public ParameterChangeIterator(IProblemState state, float[] stepSizes)
	{
		super(state);
		currentIndex = 0;
		decreased = false;
		this.stepSizes = stepSizes;
	}

	/**
	 * fetches the next Operator
	 */
	@Override
	protected void fetchNext()
	{
		if (currentIndex >= stepSizes.length) {
			// no more elements in the iterator
			nextElement = null;
			return;
		}

		IIndividuum individuum = (IIndividuum) state;

		if (!decreased) {
			float parameterValue = individuum.getChromosom()[currentIndex] - stepSizes[currentIndex];
			nextElement = new ParameterChangeOperator(
					"Change-" + currentIndex + ":" + parameterValue, 1.0f, currentIndex, parameterValue);
			decreased = true;
		} else {
			float parameterValue = individuum.getChromosom()[currentIndex] + stepSizes[currentIndex];
			nextElement = new ParameterChangeOperator(
					"Change+" + currentIndex + ":" + parameterValue, 1.0f, currentIndex, parameterValue);
			decreased = false;
			currentIndex++;
		}
	}
}
