/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package kdo.domain.model;

import java.util.Arrays;

import kdo.domain.IGeneticProblem;
import kdo.domain.IIndividuum;
import kdo.domain.IProblemState;

/**
 * Allows state transitions by adjusting one of the parameters
 * @author dorer
 */
public class ParameterChangeOperator extends Operator
{
	/** index of the parameter to change */
	private int parameterIndex;

	/** value of the parameter to change */
	private float parameterValue;

	/**
	 * @param name name of the operator to display
	 * @param cost the cost for applying this operator
	 * @param parameterIndex index of the parameter to change
	 * @param parameterValue new value for the parameter when applying this
	 *        operator
	 */
	public ParameterChangeOperator(String name, float cost, int parameterIndex, float parameterValue)
	{
		super(name, cost);
		this.parameterIndex = parameterIndex;
		this.parameterValue = parameterValue;
	}

	@Override
	public IProblemState getSuccessorState(IProblemState state)
	{
		float[] oldChromosom = ((IIndividuum) state).getChromosom();
		float[] newChromosom = Arrays.copyOf(oldChromosom, oldChromosom.length);
		newChromosom[parameterIndex] = parameterValue;
		return ((IGeneticProblem) state.getProblem()).createIndividuum(newChromosom);
	}
}
