/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.domain.model;

import java.util.Iterator;

import kdo.domain.IIndividuum;
import kdo.domain.IOperator;
import kdo.domain.IProblemState;

/**
 * Base class for Parameter adjustment neighborhood
 */
public class ParameterIterator extends OperatorIteratorBase implements Iterator<IOperator>
{
	/**
	 * stepSizes array containing the delta values by which to adjust each
	 * parameter
	 */
	private float[] stepSizes;

	private final float[] minValues;

	private final float[] maxValues;

	private float[] parameterValues;

	private boolean isFirstCall;

	/**
	 * Default constructor
	 * @param stepSizes array containing the delta values by which to adjust each
	 *        parameter
	 */
	public ParameterIterator(IProblemState state, float[] stepSizes, float[] minValues, float[] maxValues)
	{
		super(state);
		this.minValues = minValues;
		this.maxValues = maxValues;
		this.stepSizes = stepSizes;
		IIndividuum individuum = (IIndividuum) state;
		parameterValues = individuum.getChromosom();
		isFirstCall = true;
	}

	/**
	 * fetches the next Operator
	 */
	@Override
	protected void fetchNext()
	{
		boolean atEnd = true;

		if (isFirstCall) {
			System.arraycopy(minValues, 0, parameterValues, 0, parameterValues.length);
			isFirstCall = false;
		} else {
			for (int i = 0; i < parameterValues.length; i++) {
				parameterValues[i] += stepSizes[i];
				if (parameterValues[i] < maxValues[i]) {
					atEnd = false;
					break;
				}
				parameterValues[i] = minValues[i];
			}
			if (atEnd) {
				// no more elements in the iterator
				nextElement = null;
				return;
			}
		}

		nextElement = new ParameterReplaceOperator("Replace", 1.0f, parameterValues.clone());
	}
}
