/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package kdo.domain.model;

import kdo.domain.IGeneticProblem;
import kdo.domain.IProblemState;

/**
 * Allows state transitions by adjusting all of the parameters
 * @author dorer
 */
public class ParameterReplaceOperator extends Operator
{
	/** values of the parameters to change */
	private float[] parameterValues;

	/**
	 * @param name name of the operator to display
	 * @param cost the cost for applying this operator
	 * @param parameterValues new value for the parameters when applying this
	 *        operator
	 */
	public ParameterReplaceOperator(String name, float cost, float[] parameterValues)
	{
		super(name, cost);
		this.parameterValues = parameterValues;
	}

	@Override
	public IProblemState getSuccessorState(IProblemState state)
	{
		return ((IGeneticProblem) state.getProblem()).createIndividuum(parameterValues);
	}
}
