/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebn;

/**
 * Interface defining all global constants for behavior networks
 */
public interface INetworkConstants {
	/** inbox processing mode value to check inbox in every EBN execution loop */
	boolean AUTO_INBOX_PROCESSING = true;

	/** allows to limit network to execute only one action during each step */
	boolean DEFAULT_CONCURRENT_ACTIONS = true;

	/** used during competence initialization to specify connections to the goals */
	boolean DEFAULT_GOAL_TRACKING = true;

	/** allows to switch off transfer function usage */
	boolean DEFAULT_TRANSFER_FUNCTION = true;

	/** inbox processing mode value to check inbox with predefined goal and rule */
	boolean GOAL_INBOX_PROCESSING = false;

	/** default way for process inbox mode */
	boolean DEFAULT_INBOX_PROCESSING = GOAL_INBOX_PROCESSING;

	/** default value for the beta network parameter */
	double DEFAULT_BETA = 0.5;

	/** default value for the delta network parameter */
	double DEFAULT_DELTA = 0.7;

	/** default value for the gain network parameter */
	double DEFAULT_GAIN = 5.0;

	/** default value for the gamma network parameter */
	double DEFAULT_GAMMA = 0.8;

	/** default value for the sigma network parameter */
	double DEFAULT_SIGMA = 0.55;

	/** default value for the theta network parameter */
	double DEFAULT_THETA = 0.8;

	/** default value for the threshold_reduction network parameter */
	double DEFAULT_THRESHOLD_REDUCTION = 0.1;

	/** Number of milliseconds used to receive message from inbox */
	long RECEIVE_TIMEOUT = 5000;
}
