/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebn;

/**
 * Base class of all network nodes
 */
abstract class NetworkNode
{
	/** the name of the node */
	private String name;

	/**
	 * Constructor
	 *
	 * @param name Node name
	 */
	NetworkNode(String name)
	{
		this.name = name;
	}

	/**
	 * Get node name
	 *
	 * @return Name
	 */
	public String getName()
	{
		return name;
	}

	/**
	 * Set node name
	 *
	 * @param name New name
	 */
	void setName(String name)
	{
		this.name = name;
	}

	/**
	 * Default implementation does nothing
	 */
	public void perform()
	{
	}

	/**
	 * Returns the activation of this network node
	 *
	 * @return Activation value
	 */
	public abstract double getActivation();

	/**
	 * Serialize this object into a string (with indentation). The default
	 * implementation just returns the node name.
	 *
	 * @param tabs Tab width
	 * @return Serialized representation as string
	 */
	public String toString(int tabs)
	{
		return getName();
	}
}
