/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebn;

/**
 * A resource proposition extends an ordinary proposition by also modelling the
 * amount of resource units used.
 */
public class ResourceProposition extends Proposition
{
	/** the amount of resource units this proposition can use */
	private final int amountUsed;

	/**
	 * Calls parent constructor, sets containing component and amountUsed
	 * attribute
	 * @param parent the containing network node of this proposition
	 * @param perceptionNode the perception node that this proposition is
	 *        associated with
	 * @param amountUsed the amount of resource units this proposition will use
	 */
	public ResourceProposition(NetworkNode parent, PerceptionNode perceptionNode, int amountUsed)
	{
		super(parent, perceptionNode, false);
		this.amountUsed = amountUsed;
	}

	/**
	 * @return the amount of resource units that this resource proposition will
	 *         use
	 */
	public int getAmountUsed()
	{
		return amountUsed;
	}

	/**
	 * @param propName name of the proposition to look for
	 * @param ebn the ebn to which we belong
	 * @return the resource node with the passed name if existing, a new resource
	 *         node otherwise
	 * @throws NetworkConfigurationException if no corresponding belief is
	 *         available to ground the perception
	 */
	@Override
	NetworkNode getOrCreateNetworkNode(String propName, ExtendedBehaviorNetwork ebn)
			throws NetworkConfigurationException
	{
		return ebn.getOrCreateResource(propName);
	}
}
