/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.agent;

import java.util.Map;

import kdo.ebn.ExtendedBehaviorNetwork;
import kdo.ebn.IEBNAction;
import kdo.ebn.IEBNPerception;
import kdo.ebn.IResourceBelief;

/**
 * interface for an agent to the devkit
 * @author Thomas Rinklin
 *
 */
public interface IEbnAgent {
	enum AgentStatus
	{
		Running,
		Stopped,
		Both
	}

	/**
	 * returns a map of all beliefs
	 * @return a map of all beliefs
	 */
	Map<String, IEBNPerception> getBeliefs();

	/**
	 * returns a map of all behaviors
	 * @return a map of all behaviors
	 */
	Map<String, IEBNAction> getBehaviors();

	/**
	 * returns a map of all resources
	 * @return a map of all resources
	 */
	Map<String, IResourceBelief> getResources();

	/**
	 * returns the agent status
	 * @return the agent status
	 */
	AgentStatus getStatus();

	/**
	 * starts the agent
	 */
	void start();

	/**
	 * stops the agent
	 */
	void stop();

	/**
	 * returns if the agent is startable
	 * @return true if the agent is startable
	 */
	boolean isStartable();

	/**
	 * returns the name of an agent
	 * @return the name of an agent
	 */
	String getName();

	/**
	 * connects or disconnects an ebn
	 * @param ebn the new ebn, or null for disconnecting
	 */
	void connectEbn(ExtendedBehaviorNetwork ebn);
}
