/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.ebnAccess;

import java.util.Iterator;

import kdo.ebn.IEBNAction;
import kdo.ebnDevKit.ebnAccess.IEbnPerception.IEbnEffect;
import kdo.ebnDevKit.ebnAccess.IEbnPerception.IEbnProposition;
import kdo.ebnDevKit.ebnAccess.IEbnResource.IEbnResourceProposition;

/**
 * interface to a competence
 * @author Thomas Rinklin
 */
public interface IEbnCompetence {
	/**
	 * returns the name of the competence
	 * @return the name of the competence
	 */
	String getName();

	double getActivation();

	double getExecutability();

	double getActivationAndExecutability();

	double getMainActivation();

	Iterator<? extends IEbnProposition> getPreconditions();

	Iterator<? extends IEbnEffect> getEffects();

	Iterator<? extends IEbnResourceProposition> getResources();

	/**
	 * checks if the perception is used from the competence
	 * @param perception perception to check
	 * @return true if it's used, false if not
	 */
	boolean perceptionIsUsed(IEbnPerception perception);

	/**
	 * checks if the resource is used from the competence
	 * @param resource resource to check
	 * @return true if it's used, false if not
	 */
	boolean isResourceUsed(IEbnResource resource);

	Iterator<IEBNAction> getActions();
}