/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.gui.ebnGraphPanel;

import javax.swing.JFrame;
import javax.swing.JScrollPane;

import kdo.ebnDevKit.ebnAccess.IEbnAccess;
import kdo.ebnDevKit.gui.DefaultEbnPanel;
import kdo.ebnDevKit.gui.ModifierActionListeners;
import kdo.ebnDevKit.gui.PopupMenuBuilder;
import kdo.ebnDevKit.gui.ebnGraphPanel.guiElements.GuiElements;

/**
 * ebn view component which displays the ebn graphically
 * @author Thomas Rinklin
 *
 */
public class EbnGraphPanel extends DefaultEbnPanel
{
	private static final long serialVersionUID = -6264330281010092566L;

	/** reference to the model */
	private final GuiElements guiElements;

	private final DrawingArea da;

	/**
	 * constructor
	 * @param parent parent JFrame (for displaying modal dialogs)
	 * @param ebnAccess reference to the model
	 * @param graphConf configuration
	 * @param enableModification enable modification features
	 */
	public EbnGraphPanel(JFrame parent, IEbnAccess ebnAccess, GraphConfiguration graphConf, boolean enableModification)
	{
		super(parent, ebnAccess);
		ModifierActionListeners modActions = new ModifierActionListeners(ebnAccess, parent);
		PopupMenuBuilder popupMenuBuilder = null;
		if (enableModification)
			popupMenuBuilder = new PopupMenuBuilder(modActions, ebnAccess);
		guiElements = new GuiElements(popupMenuBuilder);
		da = new DrawingArea(guiElements, graphConf, popupMenuBuilder);
		this.add(new JScrollPane(da));
	}

	@Override
	protected void ebnValuesChanged()
	{
		guiElements.refreshAllValues();
		repaint();
	}

	@Override
	protected void ebnStructureChanged()
	{
		guiElements.update(ebnAccess);
		guiElements.refreshAllValues();
		repaint();
	}

	@Override
	public void start()
	{
		super.start();
	}

	@Override
	public void stop()
	{
		super.stop();
	}
}
