/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.gui.ebnGraphPanel.guiElements.nodes;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics2D;
import java.awt.Point;

import javax.swing.JPopupMenu;

import kdo.ebnDevKit.ebnAccess.IEbnPerception;
import kdo.ebnDevKit.gui.PopupMenuBuilder;

/**
 * perception gui element
 * @author Thomas Rinklin
 *
 */
public class GuiPerception extends GuiNode implements Comparable<GuiPerception>
{
	private final IEbnPerception perception;

	private String name;

	private double truthValue;

	private JPopupMenu menu;

	public GuiPerception(IEbnPerception perception2, PopupMenuBuilder popupMenuBuilder)
	{
		super(popupMenuBuilder);
		this.perception = perception2;

		if (popupMenuBuilder != null)
			menu = popupMenuBuilder.getPerceptionMenu(perception);

		refreshValues();
	}

	@Override
	public void refreshValues()
	{
		this.name = perception.getName();
		this.truthValue = perception.getTruthValue();
	}

	@Override
	public void draw(Graphics2D g)
	{
		int percSize = graphConf.getPercSize();

		Color bgColor = new Color((int) (255 * truthValue), 0, 0);
		drawBorderCircle(g, percSize, bgColor, offset); // inner circle
		if (isSelected())
			g.fillOval(offset.x, offset.y, 4, 4);

		updateDrawedArea(new Point(percSize, percSize));
		updateClickarea(percSize);

		// create font
		int textOffset = (graphConf.getPercSize() / 2);
		String text = name;
		drawStringDefault(g, textOffset, text);
	}

	@Override
	public void showMenu(Component invoker, Point point)
	{
		if (menu != null)
			menu.show(invoker, point.x, point.y);
	}

	public IEbnPerception getPerception()
	{
		return perception;
	}

	@Override
	public int compareTo(GuiPerception o)
	{
		return perception.getName().compareTo(o.perception.getName());
	}

	public Point getTopConnectionPoint()
	{
		return new Point(offset.x + (graphConf.getPercSize() / 2), offset.y);
	}
}
