/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.gui.ebnGraphPanel.guiElements.nodes;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics2D;
import java.awt.Point;

import javax.swing.JPopupMenu;

import kdo.ebnDevKit.ebnAccess.IEbnResource;
import kdo.ebnDevKit.gui.PopupMenuBuilder;

/**
 * resource gui element
 * @author Thomas Rinklin
 */
public class GuiResource extends GuiNode implements Comparable<GuiResource>
{
	private final IEbnResource resource;

	private String name;

	private JPopupMenu menu;

	private int amountAvailable;

	private int maxAmount;

	public GuiResource(IEbnResource res, PopupMenuBuilder popupMenuBuilder)
	{
		super(popupMenuBuilder);
		this.resource = res;

		if (popupMenuBuilder != null)
			menu = popupMenuBuilder.getResourceMenu(resource);
	}

	@Override
	public void refreshValues()
	{
		name = resource.getName();
		amountAvailable = resource.getAmountAvailable();
		maxAmount = resource.getMaximalAmount();
	}

	@Override
	public void draw(Graphics2D g)
	{
		int resSize = graphConf.getResourceSize();

		if (isSelected())
			g.fillOval(offset.x - 2, offset.y - 2, 4, 4);

		Color bgColor = new Color((int) ((255.0 * amountAvailable) / maxAmount), 0, 0);
		drawBorderCircle(g, resSize, bgColor, offset); // inner circle

		updateDrawedArea(new Point(resSize, resSize));
		updateClickarea(resSize);

		// create font
		int textOffset = (graphConf.getResourceSize() / 2);
		String text = name + " " + amountAvailable;
		drawStringDefault(g, textOffset, text);
	}

	@Override
	public void showMenu(Component invoker, Point point)
	{
		if (menu != null)
			menu.show(invoker, point.x, point.y);
	}

	@Override
	public int compareTo(GuiResource o)
	{
		return resource.getName().compareTo(o.resource.getName());
	}

	public Point getTopConnectionPoint()
	{
		return new Point(offset.x + (graphConf.getResourceSize() / 2), offset.y);
	}
}
