/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.staubs.decision.behavior;

import kdo.ebn.IEBNAction;
import kdo.ebnDevKit.staubs.model.IStaubs;

/**
 * Parent class for all behaviors
 *
 * @author Thomas Rinklin
 */
public abstract class Behavior implements IEBNAction
{
	/** the name of this behavior */
	private final String name;

	/** link to the world model */
	final IStaubs model;

	/**
	 * Default constructor for Behaviors
	 *
	 * @param name Behavior name
	 * @param model World model
	 */
	Behavior(String name, IStaubs model)
	{
		this.name = name;
		this.model = model;
	}

	@Override
	public final String getName()
	{
		return name;
	}

	/**
	 * By default, behaviors are finished immediately
	 * @see kdo.ebn.IEBNAction#isFinished()
	 */
	@Override
	public boolean isFinished()
	{
		return true;
	}

	@Override
	public float getIntensity()
	{
		return 0;
	}

	@Override
	public void setIntensity(float intensity)
	{
	}
}
