/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/
package kdo.ebnDevKit.staubs.model;

import kdo.util.observer.IObserver;

/**
 *
 * @author Thomas Rinklin
 */
public interface IStaubs {
	/**
	 * returns the dirt
	 * @return level of dirt (between 0 and 1)
	 */
	double getDirt();

	/**
	 * returns the energy
	 * @return level of energy (between 0 and 1)
	 */
	double getEnergy();

	/**
	 * Sets or unsets action to clean
	 * @param clean true if the agent should clean, false if not
	 */
	void clean(boolean clean);

	/**
	 * Sets or unsets action to charge
	 * @param charge true if the agent should charge battery, false if not
	 */
	void charge(boolean charge);

	/**
	 * attaches an model observer
	 * @param newObserver object which wants to be informed
	 */
	void attachModel(IObserver<IStaubs> newObserver);

	/**
	 * detaches an model observer
	 * @param oldObserver object which not wants to be informed no more
	 * @return true if the object was in the list
	 */
	boolean detachModel(IObserver<IStaubs> oldObserver);

	/**
	 * attaches an decisionmaker
	 * @param newObserver object which wants to be informed when it's time to
	 *        decide
	 */
	void attachDecisionMaker(IObserver<IStaubs> newObserver);

	/**
	 * detaches an decisionmaker
	 * @param oldObserver object which not wants to be informed no more
	 * @return true if the object was in the list
	 */
	boolean detachDecisionMaker(IObserver<IStaubs> oldObserver);

	/**
	 * enable or disables the autotick
	 * @param autoTick true to enable, false to disable
	 */
	void setAutoTick(boolean autoTick);

	/**
	 * returns the autotick status
	 * @return true, if autotick is enabled, false if not
	 */
	boolean isAutoTick();

	/**
	 * returns the cleaning status
	 * @return true if the agent is cleaning, false if not
	 */
	boolean isCleaning();

	/**
	 * returns the charging status
	 * @return true if the agent id charging, false if not
	 */
	boolean isCharging();

	/**
	 * do a manual tick
	 */
	void tick();

	public double getStress();

	void chill(boolean b);
}
