/*
 * Lecture symbolic AI, FH-Furtwangen
 * Original Author: Klaus Dorer
 */
package kdo.reinforcement;

import java.util.List;

import kdo.domain.IOperator;
import kdo.domain.IProblemState;

/**
 * Performs the update of the value function according to the temporal
 * difference approach.
 *
 * @author KDorer
 */
public class TemporalDifference implements IValueFunctionUpdate
{
	/*
	 * (non-Javadoc)
	 *
	 * @see kdo.reinforcement.IValueFunctionUpdate#update(domain.ProblemState,
	 * java.util.List)
	 */
	@Override
	public void update(IProblemState currentState, List<IProblemState> percepts, IOperator lastAction)
	{
		if (currentState.checkGoalState()) {
			// for goal states we can simply calculate the running average
			currentState.onExploration();
			int count = currentState.getExplorationCount();
			currentState.setUtility(
					(currentState.getUtility() * (count - 1) + currentState.getReinforcement()) / count);
		}

		if (percepts.size() > 1) {
			// we have a state transition so apply TD update rule
			IProblemState penultimateState = percepts.get(percepts.size() - 2);
			penultimateState.onExploration();
			float learnrate = getAlpha(penultimateState.getExplorationCount());
			float utility = penultimateState.getUtility();
			float reinforcement = penultimateState.getReinforcement();
			// td update rule
			penultimateState.setUtility(utility + learnrate * (reinforcement + currentState.getUtility() - utility));
		}
	}

	/**
	 * Calculates the learnrate as decreasing function of the passed exploration
	 * count
	 * @param explorationCount the number of visits of a state
	 * @return the learnrate as decreasing function of the passed exploration
	 *         count
	 */
	private float getAlpha(int explorationCount)
	{
		// return (float) (Math.exp(-explorationCount * 0.006));
		// return Math.max(0.0f, (1000 - explorationCount) / 1000.0f);
		// return 2.0f / (2.0f + explorationCount);
		return 0.5f;
	}
}
