/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package kdo.search.strategy.local;

import kdo.domain.IProblemState;

/**
 * Runs a specified number of random state sampling
 * @author dorer
 */
public class RandomSampling extends LocalSearchBase
{
	/** the number of random samples to take */
	private long howManySamples;

	/**
	 * Default constructor
	 */
	public RandomSampling(long maxRuntime, long howManySamples)
	{
		super("RandomSampling", null, maxRuntime);
		this.howManySamples = howManySamples;
	}

	@Override
	public IProblemState search(IProblemState startState)
	{
		onStartSearch();
		IProblemState bestState = startState;
		double bestUtility = startState.getUtility();

		for (int i = 0; i < howManySamples && !canStop(); i++) {
			IProblemState randomState = startState.getProblem().getRandomState();
			double utility = randomState.getUtility();
			if (utility > bestUtility) {
				bestUtility = utility;
				bestState = randomState;
			}
		}
		return bestState;
	}
}
