/*******************************************************************************
 * Copyright 2008, 2012 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber, Fabian Korak,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Ingo Schindler, Rajit Shahi, Bjoern Weiler
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 *******************************************************************************/

package kdo.search.strategy.local;

import kdo.domain.IProblemState;
import kdo.search.impl.StrategyBase;
import kdo.search.strategy.ILocalSearchStrategy;

/**
 * Simply takes the passed state and calculates its utility
 * @author dorer
 */
public class UtilityMeasurement extends StrategyBase implements ILocalSearchStrategy
{
	private int repeats;

	public UtilityMeasurement()
	{
		this(1);
	}

	/**
	 * Allows to repeat a measurement. Only good for printing each single
	 * measurement. It does not average the results! If you want averaged results
	 * use AverageOutStrategy and default constructor.
	 */
	public UtilityMeasurement(int repeats)
	{
		super("UtilityMeasurement", null);
		this.repeats = repeats;
	}

	@Override
	public IProblemState search(IProblemState stateToEvaluate)
	{
		for (int i = 0; i < repeats; i++) {
			stateToEvaluate.setUtility(-1.0102f);
			double utility = stateToEvaluate.getUtility();
			double[] runtimeProperties = stateToEvaluate.getRuntimeProperties();
			if (runtimeProperties == null) {
				runtimeProperties = new double[1];
				runtimeProperties[0] = utility;
			}
		}
		return stateToEvaluate;
	}
}
