/*
 * Copyright (c) 2007 Klaus Dorer
 * Hochschule Offenburg
 */
package kdo.search.strategy.local.genetic;

import java.util.List;

import kdo.domain.IOptimizationState;

/**
 * @author klaus
 *
 */
public interface IOptimizationStateGroup {
	/**
	 * @return the best state of the stateGroup according to the fitness
	 *         function, null if utility calculation is expensive and we have not
	 *         breeded yet
	 */
	IOptimizationState getBestState();

	/**
	 * Creates a randomly created state from the application domain this
	 * stateGroup is based on. The state is not added to the stateGroup.
	 * @return a randomly created state from the application domain this
	 *         stateGroup is based on
	 */
	public IOptimizationState createRandomState();

	/**
	 * @return the number of states in the stateGroup
	 */
	int getSize();

	/**
	 * @return the number of generations this stateGroup has been breeded
	 */
	int getIterations();

	/**
	 * @return the average diversity of all genes in the stateGroup
	 */
	public float getAverageDiversity();

	/**
	 * @return the time that breeding has taken until now
	 */
	public long getRuntime();

	/**
	 * @return returns a sorted list of all states
	 */
	public List<IOptimizationState> getSortedStates();

	/**
	 * @return true if the utilities have once been calculated, false for a fresh
	 *         created stateGroup
	 */
	boolean isUtilitiesCalculated();
}
