/* Copyright 2009 Hochschule Offenburg
 * Klaus Dorer, Mathias Ehret, Stefan Glaser, Thomas Huber,
 * Simon Raffeiner, Srinivasa Ragavan, Thomas Rinklin,
 * Joachim Schilling, Rajit Shahi
 *
 * This file is part of magmaOffenburg.
 *
 * magmaOffenburg is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * magmaOffenburg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with magmaOffenburg. If not, see <http://www.gnu.org/licenses/>.
 */

package kdo.util.learningParameter;

import java.util.HashMap;

import kdo.util.parameter.IParameterList;
import kdo.util.parameter.ParameterList;
import kdo.util.parameter.ParameterMap;

/**
 * @author kdorer
 */
public class LearningParameterMap
{
	private ILearningParameterList parameter;

	private String[] mapNames;

	public LearningParameterMap(String mapName, ILearningParameterList parameter)
	{
		this.parameter = parameter;
		this.mapNames = new String[1];
		mapNames[0] = mapName;
	}

	/**
	 * Use this constructor, if the parameter set should be accessed by multiple
	 * instances (names).
	 * @param names array of names under which the parameters should be
	 *        accessible.
	 */
	public LearningParameterMap(String[] names, ILearningParameterList parameter)
	{
		this.parameter = parameter;
		this.mapNames = names;
	}

	/**
	 * Creates an empty dummy map.
	 */
	public LearningParameterMap()
	{
		parameter = new LearningParameterList(new ParameterList(), new HashMap<>());
		mapNames = new String[0];
	}

	public ILearningParameterList getParameter()
	{
		return parameter;
	}

	public IParameterList getDecoratedParameter()
	{
		return parameter.getDecoratedList();
	}

	/**
	 * Creates a parameter map from the information in this class.
	 * @return the corresponding ParameterMap instance
	 */
	public ParameterMap getParameterMap()
	{
		ParameterMap map = new ParameterMap();
		for (String name : mapNames) {
			map.put(name, getDecoratedParameter());
		}
		return map;
	}
}
